pub(crate) fn mount_tmpfs_for_overlay() -> Result<OwnedFd>Expand description
Mount a tmpfs to use as the upper layer for an overlay.
TODO: sync these options with systemd’s root mounting, there’s some tweaks there for default tmpfs and we may want to make this configurable anyways i nthe future